@@ -83,66 +83,44 @@ def strip_escape_quotes(value: str) -> str:
 
 def format_variables_multiline(variables: Dict[str, Any], prefix: str, max_line_length: int = 120) -> str:
     """
-    Format variables into multi-line aligned display.
+    Format variables into vertical list display.
+
+    This function creates a clean vertical list where each variable is on its own
+    line with consistent 2-space indentation, making it easy to read and scan.
 
     Args:
         variables: Dictionary of variable name-value pairs
         prefix: The prefix string (e.g., "[CONFIG] variables: ")
         max_line_length: Maximum line length before wrapping (default: 120)
+        Note: This parameter is kept for backward compatibility but not used in vertical format
 
     Returns:
-        Multi-line formatted string with proper alignment
+        Multi-line formatted string with each variable on its own line
     """
     if not variables:
         return prefix.rstrip() if prefix.endswith(": ") else prefix
 
-    # Format all variable assignments
-    var_assignments = [f"{k}={strip_escape_quotes(str(v))}" for k, v in variables.items()]
+    # Format all variable assignments with escape quotes removed
+    var_assignments = [f"{k}: {strip_escape_quotes(str(v))}" for k, v in variables.items()]
 
-    # Calculate prefix length for alignment
-    prefix_len = len(prefix)
+    # Return vertical list format with proper indentation
+    # Remove trailing colon/space from prefix if present, then add single colon
+    clean_prefix = prefix.rstrip()
+    if not clean_prefix.endswith(":"):
+        clean_prefix += ":"
 
-    # Check if we can fit all variables on one line with the prefix
-    all_vars = ", ".join(var_assignments)
-    if prefix_len + len(all_vars) <= max_line_length:
-        # Fits on one line
-        return prefix + all_vars
-
-    # Need to split into multiple lines
-    lines = []
-
-    # First line: prefix + as many vars as fit
-    first_line_vars = []
-    current_length = prefix_len
-
-    for var in var_assignments:
-        # Add 2 for ", " separator (except for first item)
-        var_length = len(var) + (2 if first_line_vars else 0)
-        if current_length + var_length <= max_line_length:
-            first_line_vars.append(var)
-            current_length += var_length
-        else:
-            break
-
-    # Ensure first line has at least one variable
-    if not first_line_vars:
-        first_line_vars = [var_assignments[0]]
-        remaining_vars = var_assignments[1:]
+    lines = [clean_prefix]
+    # Calculate indentation to align with the colon in the prefix
+    colon_pos = clean_prefix.find(":")
+    if colon_pos != -1:
+        # Align variables with the colon position
+        indentation = " " * (colon_pos + 1)  # +1 to align after the colon
     else:
-        remaining_vars = var_assignments[len(first_line_vars):]
+        # Fallback to 2-space indentation if no colon found
+        indentation = "  "
 
-    # Add the first line
-    lines.append(prefix + ", ".join(first_line_vars))
-
-    # Subsequent lines: space-prefix + as many vars as fit
-    for var in remaining_vars:
-        var_length = len(var) + 2  # +2 for ", " separator
-        if len(lines[-1]) + var_length <= max_line_length:
-            # Append to current line
-            lines[-1] += ", " + var
-        else:
-            # Start a new line
-            lines.append(" " * prefix_len + var)
+    for var_assignment in var_assignments:
+        lines.append(indentation + var_assignment)
 
     return "\n".join(lines)
 
