@@ -55,15 +55,52 @@ class Runner:
 
     def _fmt_json(self, obj: Any) -> str:
         try:
-            return json.dumps(obj, ensure_ascii=False, indent=2)
+            # Process object to strip escape quotes from string values
+            processed_obj = self._strip_escape_quotes_from_obj(obj)
+            return json.dumps(processed_obj, ensure_ascii=False, indent=2)
         except Exception:
             return str(obj)
 
-    @staticmethod
-    def _format_log_value(value: Any, *, prefix_len: int = 0) -> str:
+    def _strip_escape_quotes_from_obj(self, obj: Any) -> Any:
+        """Recursively strip escape quotes from string values in an object.
+
+        This processes JSON-like structures (dict, list, and strings) to remove
+        escape quotes that were added during YAML parsing, making the output
+        cleaner and more readable.
+        """
+        if isinstance(obj, str):
+            # First try strip_escape_quotes for template expressions
+            cleaned = strip_escape_quotes(obj)
+
+            # If the original string had escape quotes and strip_escape_quotes didn't change it,
+            # we need to handle the escaped quotes manually
+            if obj == cleaned and ('\\"' in obj or '\\\'' in obj):
+                # This string has escaped quotes that weren't processed by strip_escape_quotes
+                # Handle common cases:
+                # 1. "value_with_\"escaped_quotes\"" -> value_with_"escaped_quotes"
+                # 2. value_with_\"escaped_quotes (without outer quotes) -> value_with_"escaped_quotes"
+                result = obj
+                # Remove outer quotes if present
+                if result.startswith('"') and result.endswith('"'):
+                    result = result[1:-1]
+                # Unescape inner quotes
+                result = result.replace('\\"', '"').replace("\\'", "'")
+                return result
+
+            return cleaned
+        elif isinstance(obj, dict):
+            return {k: self._strip_escape_quotes_from_obj(v) for k, v in obj.items()}
+        elif isinstance(obj, list):
+            return [self._strip_escape_quotes_from_obj(item) for item in obj]
+        else:
+            return obj
+
+    def _format_log_value(self, value: Any, *, prefix_len: int = 0) -> str:
         if isinstance(value, (dict, list)):
             try:
-                text = json.dumps(value, ensure_ascii=False, indent=2)
+                # Process object to strip escape quotes from string values
+                processed_obj = self._strip_escape_quotes_from_obj(value)
+                text = json.dumps(processed_obj, ensure_ascii=False, indent=2)
                 pad = "\n" + " " * max(prefix_len, 0)
                 return text.replace("\n", pad)
             except Exception:
@@ -361,9 +398,10 @@ class Runner:
 
         # Evaluate case-level variables once to fix values across steps
         base_vars_raw: Dict[str, Any] = {**(case.config.variables or {}), **(params or {})}
-        rendered_base = self._render(base_vars_raw, {}, funcs, envmap)
-        if not isinstance(rendered_base, dict):
-            rendered_base = base_vars_raw
+        # Resolve sequentially so variables can reference earlier ones
+        rendered_base = {}
+        for key, value in base_vars_raw.items():
+            rendered_base[key] = self._render(value, rendered_base, funcs, envmap)
         ctx = VarContext(rendered_base)
         client = self._build_client(case)
 
@@ -497,10 +535,9 @@ class Runner:
                     # Print step variables if present
                     step_vars = step.variables or {}
                     if step_vars:
+                        # Format variables with proper indentation
                         vars_str = format_variables_multiline(step_vars, "[STEP] variables: ")
-                        for line in vars_str.split("\n"):
-                            if line.strip():
-                                self.log.info(line)
+                        self.log.info(vars_str)
 
                     # brief request line
                     self.log.info(f"[REQUEST] {req_rendered.get('method','GET')} {req_rendered.get('path')}")
@@ -605,17 +642,42 @@ class Runner:
                         self.log.info(self._fmt_aligned("RESP", "headers", self._fmt_json(hdrs)))
                     
                     if is_stream:
-                        # For streaming, show summary instead of full events
+                        # For streaming, show progressive content instead of full events
                         stream_events = resp_obj.get("stream_events", [])
+                        progressive_content = resp_obj.get("progressive_content", [])
+                        
                         if stream_events:
                             self.log.info(f"[STREAM] {len(stream_events)} events received")
-                            # Show first and last events
-                            if len(stream_events) > 0:
-                                first_event = stream_events[0]
-                                self.log.info(self._fmt_aligned("STREAM", "first event", self._fmt_json(first_event)))
-                            if len(stream_events) > 1:
-                                last_event = stream_events[-1]
-                                self.log.info(self._fmt_aligned("STREAM", "last event", self._fmt_json(last_event)))
+                            
+                            # Show progressive content if available
+                            if progressive_content:
+                                # Show each event that contains content with full JSON structure
+                                chunk_num = 0
+                                for event in stream_events:
+                                    event_data = event.get("data")
+                                    if event_data and isinstance(event_data, dict):
+                                        choices = event_data.get("choices", [])
+                                        if choices and len(choices) > 0:
+                                            delta = choices[0].get("delta", {})
+                                            if delta.get("content"):
+                                                chunk_num += 1
+                                                self.log.info(self._fmt_aligned("STREAM", f"Chunk {chunk_num}", self._fmt_json(event)))
+                                
+                                # Show final summary
+                                if progressive_content:
+                                    final_chunk = progressive_content[-1]
+                                    final_content = final_chunk.get("content", "")
+                                    final_time = final_chunk.get("timestamp_ms", 0)
+                                    self.log.info(f"[STREAM] 完成 ({final_time:.0f}ms)，最终内容：")
+                                    self.log.info(final_content)
+                            else:
+                                # Fallback: show first and last events if progressive content not available
+                                if len(stream_events) > 0:
+                                    first_event = stream_events[0]
+                                    self.log.info(self._fmt_aligned("STREAM", "event[0]", self._fmt_json(first_event)))
+                                if len(stream_events) > 1:
+                                    last_event = stream_events[-1]
+                                    self.log.info(self._fmt_aligned("STREAM", f"event[{len(stream_events)-1}]", self._fmt_json(last_event)))
                     else:
                         # Regular response body logging
                         body_preview = resp_obj.get("body")
