@@ -5,6 +5,7 @@ Drun 项目脚手架模板集合。
 """
 
 from .templates import (
+    ASSERTIONS_TESTCASE,
     CONVERTS_README,
     CSV_DATA_TESTCASE,
     CSV_DATA_TESTSUITE,
@@ -15,6 +16,8 @@ from .templates import (
     ENV_TEMPLATE,
     GITIGNORE_TEMPLATE,
     GITKEEP_CONTENT,
+    GITHUB_WORKFLOW_TEMPLATE,
+    GITLAB_CI_TEMPLATE,
     HEALTH_TESTCASE,
     HOOKS_TEMPLATE,
     SAMPLE_CURL,
@@ -27,6 +30,7 @@ from .templates import (
 )
 
 __all__ = [
+    "ASSERTIONS_TESTCASE",
     "CONVERTS_README",
     "CSV_DATA_TESTCASE",
     "CSV_DATA_TESTSUITE",
@@ -37,6 +41,8 @@ __all__ = [
     "ENV_TEMPLATE",
     "GITIGNORE_TEMPLATE",
     "GITKEEP_CONTENT",
+    "GITHUB_WORKFLOW_TEMPLATE",
+    "GITLAB_CI_TEMPLATE",
     "HEALTH_TESTCASE",
     "HOOKS_TEMPLATE",
     "README_TEMPLATE",
